#ifndef RFSYSINFO_H
#define RFSYSINFO_H

#include <sys/types.h>
#include <qvariant.h>
#include <qwidget.h>
#include <qptrlist.h>
#include <qstring.h>

#define _AIX 1
#include "sysinfo.h"
extern "C"
{
#include "lib/sysinfo/include/getinfo.h"
}

#include <qlistview.h>
#include <qregexp.h>

/* for ipaddress */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <unistd.h>
#include <sys/socket.h>
#include <sys/ioctl.h>
#include <net/if.h>
#include <net/if_arp.h>
#include <arpa/inet.h>

#define inaddrr( x ) ( *( struct in_addr * )&ifr->x[ sizeof( sa.sin_port ) ] )
#define IFRSIZE ( ( int )( size * sizeof( struct ifreq ) ) )
/* end for */


/* defines for images */
#define ICONPATH "/usr/share/rfsysinfo/gif/"

#define IMG_MAIN	ICONPATH"main.xpm"
#define IMG_GENERAL 	ICONPATH"general.xpm"
#define IMG_SYSCONF 	ICONPATH"sysconf.xpm"
#define IMG_DEVICE  	ICONPATH"hardware.xpm"
#define IMG_PARTITION 	ICONPATH"partition.xpm"

#define IMG_PARA 	ICONPATH"para.xpm"
#define IMG_DRIVE 	ICONPATH"hdd.xpm"
//#define IMG_GENERIC 	ICONPATH"general.xpm"
#define IMG_GENERIC 	ICONPATH"unknown.xpm"
#define IMG_DISKDRIVE	ICONPATH"hdd.xpm"
#define IMG_DISKCTRL 	ICONPATH"disk_control.xpm"
#define IMG_TAPE 	ICONPATH"tape.xpm"
#define IMG_TAPECTRL 	ICONPATH"tape.xpm"
#define IMG_FRAMEBUF	ICONPATH"graphics.xpm"
#define IMG_GRAPHICS 	ICONPATH"graphics.xpm"
#define IMG_NET	 	ICONPATH"network.xpm"
#define IMG_SYSTEMBUS 	ICONPATH"disk_control.xpm"
#define IMG_BRIDGE 	ICONPATH"disk_control.xpm"
#define IMG_GENERALCTRL	ICONPATH"disk_control.xpm"
#define IMG_CPU	 	ICONPATH"cpu.xpm"
#define IMG_MEMORY 	ICONPATH"memory.xpm"
#define IMG_KEYBOARD 	ICONPATH"keyboard.xpm"
#define IMG_CDROM 	ICONPATH"cdrom.xpm"
#define IMG_SERIAL 	ICONPATH"serial.xpm"
#define IMG_PARALLEL 	ICONPATH"para.xpm"
#define IMG_GENERALCARD	ICONPATH"generic_card.xpm"
#define IMG_AUDIO 	ICONPATH"audio.xpm"
#define IMG_MFCARD 	ICONPATH"multi_f_card.xpm"
#define IMG_MOUSE 	ICONPATH"mouse.xpm"
#define IMG_MONITOR 	ICONPATH"monitor.xpm"
#define IMG_FLOPPY 	ICONPATH"floppy.xpm"
#define IMG_FLOPPYCTRL 	ICONPATH"floppy.xpm"
#define IMG_PRINTER 	ICONPATH"printer.xpm"
#define IMG_WORM 	ICONPATH"unknown.xpm"
#define IMG_SCANNER 	ICONPATH"scanner.xpm"
#define IMG_CONSOLE 	ICONPATH"console.xpm"
#define IMG_DVD	 	ICONPATH"dvd.xpm"
#define IMG_BOIS 	ICONPATH"bios.xpm"
#define IMG_SYSBOARD 	ICONPATH"mainboard.xpm"
#define IMG_ENLOSURE 	ICONPATH"enclosure.xpm"
#define IMG_MEMCTRL 	ICONPATH"memory.xpm"

#define IMG_UNKNOWN	ICONPATH"unknown.xpm"


class 	NetInf;

static 	QRegExp reg("^(\\w+)(\\d+)");
typedef QValueList<QString> StringList;

int match(const QString& str, const QString& pattern, QStringList& caps, int pos[],bool caseSensitive = FALSE);

int getMacList(QPtrList<NetInf>& netInfs);
int runcmd(const QString& cmd, const QString& arg, QString& output);
int handleScsiKernelModule(QWidget* parent, const bool action);
	
class NetInf 
{
public:
        QString name;           /* eth0, eth1... */
        QString ip;
        QString mac;
};

class RFSysInfo : public SysInfo 
{ 
    Q_OBJECT

public:
	RFSysInfo(SysInfo* parent= 0, const char* name = 0, WFlags fl = 0 );
	~RFSysInfo();
	
	Define_t* 	sysconf_head;
	PartInfo_t* 	part_head;
	GeneralInfo_t* 	general_head;  
	DevInfo_t*	dev_head;
//    SoftInfo_t* 	soft_head;

    	QString 	str_ipaddress;
	QString 	str_memory;
	QString		str_mac;
	QString		str_cpuname;
	QString 	str_cpuspeed;
	    
	QString  	transtype(int id);
	void 		getCPUModelNameList();
   
private:
    
    	StringList 	iplist;
	StringList	maclist;
	StringList	cpunamelist;    
	StringList	cpuspeedlist;
    
	void 		show_general();
	void 		show_sysconf();
	void 		show_partition_old(); // obsolete
	void 		show_partition();
	void 		show_device_bc();
	void 		show_device_bt();
//    	void show_software();
	void 		init_members();	
	StringList 	get_iplist();

	void 		gethardware_bc(DevInfo_t* dev,QListViewItem* list);
	void 		gethardware_bt(DevInfo_t* dev,QListViewItem* list);
	
//    void getsoft(SoftInfo_t* soft,QListViewItem* l);
	QString  	insertmap(QListViewItem* Lst,int id);  
	void 		show_devdetail(DevInfo_t* dev,QListViewItem* Lst,int id);
	int 		filter_bt(DevInfo_t* dev,QListViewItem* Lst,int id);

	void 		init_toolbar();
	void 		item_setselected(const QString& string);

	void 		action_seton(const QString& string);
	void 		helpAbout();
	
public slots:

	void 		iconitem_select(QIconViewItem* item );
	void 		output();
	void 		helpContents();
    
};

class SortedListViewItem : public QListViewItem
{
public:
      SortedListViewItem(QListView * parent,  QString label1, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null, QString label7 = QString::null, QString label8 = QString::null) :
	                 QListViewItem(parent, label1, label2, label3, label4, label5, label6, label7, label8) {}

      SortedListViewItem ( QListViewItem * parent, QString label1, QString label2 = QString::null, QString label3 = QString::null, QString label4 = QString::null, QString label5 = QString::null, QString label6 = QString::null, QString label7 = QString::null, QString label8 = QString::null ) :
	                 QListViewItem(parent, label1, label2, label3, label4, label5, label6, label7, label8) {}

      virtual int	compare ( QListViewItem * i, int col, bool ascending ) const;
};


#endif // RFSYSINFO_H
